@@ -43,6 +43,9 @@ DMainWindowPrivate::DMainWindowPrivate(DMainWindow *qq)
     titlebar = new DTitlebar(qq);
     titlebar->setAccessibleName("DMainWindowTitlebar");
     auto noTitlebarEnabled = []{
+        if (qEnvironmentVariable("DDE_CURRENT_COMPOSITOR") == "TreeLand") {
+            return true;
+        }
         QFunctionPointer enableNoTitlebar = qApp->platformFunction("_d_isEnableNoTitlebar");
         bool enabled = qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
         return enabled && enableNoTitlebar != nullptr;
